<?php

namespace Drush\Commands\dcq;

use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 *
 * See these files for an example of injecting Drupal services:
 *   - http://cgit.drupalcode.org/devel/tree/src/Commands/DevelCommands.php
 *   - http://cgit.drupalcode.org/devel/tree/drush.services.yml
 */
class DcqCommands extends DrushCommands {

  /**
   * Install DCQ (Drupal Code Quality) git hooks.
   *
   * @param array $options An associative array of options whose values come
   *   from cli, aliases, config, etc.
   * @option force
   *   Overwrite existing pre-commit hook files.
   *
   * @command dcq:install
   * @aliases dcq,dcq-install
   */
  public function install(array $options = ['force' => null]) {
    $source_dir = dirname(realpath(__FILE__));
    $dest_dir = exec('git rev-parse --show-toplevel');

    if (empty($dest_dir)) {
      return throw new \Exception('No git directory was found.');
    }

    if ($dest_dir) {
      chdir($dest_dir);
      $default = '.git' . DIRECTORY_SEPARATOR . 'hooks';
      $dest_dir = realpath(exec("git config --get --default $default core.hookspath"));
      $files = array('pre-commit', 'pre-commit_dcq');

      // Check for existing pre-commit hook files.
      $file_exists = FALSE;
      foreach ($files as $file) {
        $dest_file = "{$dest_dir}/{$file}";
        if (file_exists($dest_file)) {
          $this->logger()->warning(dt('File @file already exists.', array('@file' => $dest_file)));
          $file_exists = TRUE;
        }
      }

      // Exit or notify the user if there are existing pre-commit hook files.
      if ($file_exists) {
        if (!$options['force']) {
          $this->logger()->error(dt('Aborting. Use --force to overwrite existing pre-commit hooks.'));
          return FALSE;
        }
        else {
          $this->logger()->warning(dt('Overwriting existing pre-commit hooks.'));
        }
      }

      // Copy the files from dcq into the .git/hooks directory.
      foreach ($files as $file) {
        copy("{$source_dir}/{$file}", "{$dest_dir}/{$file}");
        chmod("{$dest_dir}/{$file}", 0755);
      }
      $this->logger()->success(dt('Installed pre-commit hooks in @dir', array('@dir' => $dest_dir)));
    }
  }

}
